@@ -38,10 +38,6 @@
 #include "zbx_scripts_constants.h"
 #include "zbx_item_constants.h"
 
-#ifdef HAVE_NETSNMP
-#	include "zbxpoller.h"
-#endif
-
 /**************************************************************************************
  *                                                                                    *
  * Purpose: executes remote command task                                              *
@@ -545,11 +541,11 @@ ZBX_THREAD_ENTRY(taskmanager_thread, args)
 	double				sec1, sec2;
 	zbx_ipc_async_socket_t		rtc;
 	const zbx_thread_info_t		*info = &((zbx_thread_args_t *)args)->info;
-	int				tasks_num, rtc_msgs_num = 1,
+	int				tasks_num, rtc_msgs_num = 2,
 					server_num = ((zbx_thread_args_t *)args)->info.server_num,
 					process_num = ((zbx_thread_args_t *)args)->info.process_num;
 	unsigned char			process_type = ((zbx_thread_args_t *)args)->info.process_type;
-	zbx_uint32_t			rtc_msgs[] = {ZBX_RTC_CONFIG_CACHE_RELOAD, ZBX_RTC_SNMP_CACHE_RELOAD};
+	zbx_uint32_t			rtc_msgs[] = {ZBX_RTC_CONFIG_CACHE_RELOAD, ZBX_RTC_TASK_MANAGER_NOTIFY};
 
 	zabbix_log(LOG_LEVEL_INFORMATION, "%s #%d started [%s #%d]", get_program_type_string(info->program_type),
 			server_num, get_process_type_string(process_type), process_num);
@@ -570,11 +566,7 @@ ZBX_THREAD_ENTRY(taskmanager_thread, args)
 	zbx_setproctitle("%s [started, idle " ZBX_FS_TIME_T " sec]", get_process_type_string(process_type),
 			(zbx_fs_time_t)sleeptime);
 
-#ifdef HAVE_NETSNMP
-	rtc_msgs_num++;
-#endif
-
-	zbx_rtc_subscribe(process_type, process_num, rtc_msgs,rtc_msgs_num,
+	zbx_rtc_subscribe(process_type, process_num, rtc_msgs, rtc_msgs_num,
 			taskmanager_args_in->config_comms->config_timeout, &rtc);
 
 	while (ZBX_IS_RUNNING())
@@ -582,12 +574,10 @@ ZBX_THREAD_ENTRY(taskmanager_thread, args)
 		zbx_uint32_t	rtc_cmd;
 		unsigned char	*rtc_data = NULL;
 
-		if (SUCCEED == zbx_rtc_wait(&rtc, info, &rtc_cmd, &rtc_data, sleeptime) && 0 != rtc_cmd)
+		while (SUCCEED == zbx_rtc_wait(&rtc, info, &rtc_cmd, &rtc_data, sleeptime) && 0 != rtc_cmd)
 		{
-#ifdef HAVE_NETSNMP
-			if (ZBX_RTC_SNMP_CACHE_RELOAD == rtc_cmd)
-				zbx_clear_cache_snmp(process_type, process_num);
-#endif
+			sleeptime = 0;
+
 			if (ZBX_RTC_CONFIG_CACHE_RELOAD == rtc_cmd &&
 					ZBX_PROXYMODE_PASSIVE == taskmanager_args_in->config_comms->proxymode)
 			{
@@ -618,6 +608,12 @@ ZBX_THREAD_ENTRY(taskmanager_thread, args)
 				taskmanager_args_in->config_ssh_key_location,
 				taskmanager_args_in->config_webdriver_url);
 
+		if (ZBX_PROXYMODE_ACTIVE == taskmanager_args_in->config_comms->proxymode && 0 != tasks_num)
+		{
+			zbx_rtc_notify_generic(&rtc, ZBX_PROCESS_TYPE_DATASENDER, 1, ZBX_RTC_TASK_MANAGER_NOTIFY,
+					NULL, 0);
+		}
+
 		if (ZBX_TM_CLEANUP_PERIOD <= sec1 - cleanup_time)
 		{
 			tm_remove_old_tasks((time_t)sec1);
